from pyCausalFS.pyBN.learning.structure.naive.naive_bayes import *
from pyCausalFS.pyBN.learning.structure.naive.TAN import *